#
# spec file for package libgnome-games-support
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 4
%define api 2

Name:           libgnome-games-support
Version:        2.0.0
Release:        1.10
Summary:        Internal support library for GNOME games
License:        LGPL-3.0-or-later
Group:          Development/Libraries/GNOME
URL:            https://git.gnome.org/browse/libgnome-games-support/
Source0:        https://download.gnome.org/sources/libgnome-games-support/2.0/%{name}-%{version}.tar.xz
Source1:        https://download.gnome.org/sources/libgnome-games-support/2.0/%{name}-%{version}.sha256sum

BuildRequires:  intltool >= 0.50.2
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.40
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.40
BuildRequires:  pkgconfig(glib-2.0) >= 2.40
BuildRequires:  pkgconfig(gtk4)

%description
libgnome-games-support is a small library intended for internal use by
GNOME Games, but it may be used by others. The API will only break
with the major version number. The ABI is unstable.

%package -n libgnome-games-support-%{api}-%{sover}
Summary:        Internal support library for GNOME games
# In order for the -lang package to be installable
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n libgnome-games-support-%{api}-%{sover}
libgnome-games-support is a small library intended for internal use by
GNOME Games, but it may be used by others. The API will only break
with the major version number. The ABI is unstable.

%package devel
Summary:        Development files for the GNOME Internal games library
Group:          Development/Libraries/C and C++
Requires:       libgnome-games-support-%{api}-%{sover} = %{version}

%description devel
libgnome-games-support is a small library intended for internal use by
GNOME Games, but it may be used by others. The API will only break
with the major version number. The ABI is unstable.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang libgnome-games-support2 %{name}.lang

%check
%meson_test

%ldconfig_scriptlets -n libgnome-games-support-%{api}-%{sover}

%files -n libgnome-games-support-%{api}-%{sover}
%license COPYING COPYING.LESSER
%{_libdir}/libgnome-games-support-%{api}.so.%{sover}*

%files devel
%{_includedir}/gnome-games-support-%{api}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/vala/

%files lang -f %{name}.lang

%changelog
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.0:
  + Updated translations.
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.0.beta.2:
  + Fix parallel-installability of localizations
- Changes from version 2.0.beta:
  + Port to GTK 4
  + New API version: libgnome-games-support-2, should be
    parallel-installable.
- Following upstreams port: Replace pkgconfig(gtk+-3.0) with
  pkgconfig(gtk4) BuildRequires, bump sover to 4 and add a new api
  define and set it to 2, renaming sub-packages to
  libgnome-games-support-2-4
* Sat Oct 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.2:
  + Add margins to category bar in scores dialog.
  + Fix build with latest vala.
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8.1:
  + Updated translations.
* Tue Sep  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.7.1:
  + Add API to set icon name.
* Thu Mar 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.1:
  + Always show category in scores dialog.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.0.1:
  + Updated translations.
- Changes from version 1.5.59:
  + Replace autotools buildsystem with meson.
- Switch to meson buildsystem following upstream changes. Add
  meson BuildRequires and macros. Also add a check section, and run
  meson_test.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.4:
  + Fix build with new gettext.
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 1.4.3:
  + Fix build with vala 0.43.1
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 1.4.2:
  + Hide category chooser on scores dialog when not needed.
- Changes from version 1.4.1:
  + Fix invalid cast in scores dialog.
- Changes from version 1.4.0:
  + Fix Scores.Context.get_high_scores() returning unordered
    scores.
  + Ensure all public objects are usable when created with
    g_object_new().
  + Build with --abi-stability (requires valac 0.40). Bump soname.
- Following upstream changes, bump soname to 3, use define sover to
  ease future bumps.
- Drop gnome-common BuildRequires and remove conditional autogen
  call, we are using a prestine tarball.
- Add make_build, actually build the libs ourselves, not just
  install the upstream ones. Use autosetup macro.
* Mon Mar  5 2018 jengelh@inai.de
- Fix SRPM group.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 1.2.3:
  + Updated translations.
* Fri Jun 16 2017 zaitor@opensuse.org
- Update to version 1.2.2:
  + Fix wrong printf format specifier.
  + Updated translations.
* Tue Oct 25 2016 zaitor@opensuse.org
- Update to version 1.2.1:
  + Do not iterate global main context when running scores dialog.
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 1.2.0:
  + Updated translations.
* Mon Aug 29 2016 zaitor@opensuse.org
- Update to version 1.0.91:
  + Rename the pkg-config file one final time... are we there yet?
  + Updated translations.
- Rename subpackage libgnome-games-support-1_0-2 to
  libgnome-games-support-1-2 following upstreams soversions
  changes, also update post/un handling.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 1.0.90:
  + Rename to libgnome-games-support at behest of Debian (sorry!).
  + Style checker fixes.
  + Updated translations.
- Rename to libgnome-games-support from libgames-support.
- Handle lib in post/un.
- Add Url to git, silence rpmlint.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 1.0.2:
  + Updated translations.
* Fri Apr  8 2016 zaitor@opensuse.org
- Update to version 1.0.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 1.0:
  + Updated translations.
* Mon Mar  7 2016 zaitor@opensuse.org
- Update to version 0.91:
  + Adjust column spacing on scores dialog.
  + Add missing mnemonic to done button on scores dialog.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 0.90:
  + Add ability to import old scores.
  + Various fixes and improvements.
  + Various API changes.
  + Updated translations.
- Rename libgames-support1 subpackage to libgames-support2,
  following upstreams soname bump.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 0.2:
  + API break: replace Context.get_best_n_scores with
    Context.get_high_scores. The new function returns a
    non-nullable Gee.List (with possibly zero elements) rather than
    a nullable GLib.List (which was never empty if non-null).
  + Updated translations.
- Rename libgames-support0 subpackage to libgames-support1,
  following upstreams soname bump.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 0.1:
  + Initial release.
* Tue Aug 18 2015 opensuse-packaging@opensuse.org
- Update to version 0.1~git.20150816:
  + Add Games.GridFrame
  + Add workaround to fix Continuous
  + Fix style checker to work with the *all* flag
  + Make the scores dialog look good when no scores are present
  + Center the "no scores yet" box
  + Fix false positive detected by style checker
  + Updated Czech translation
  + Updated Polish translation
  + Minor style tweak
  + Even out spacing between columns in the high scores dialog.
* Tue Mar 31 2015 dimstar@opensuse.org
- Initial package.
